==> nextcloud-28.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/fa.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "می‌خواهید هم‌رسانی دوردست {name} را از ‪{owner}@{remote}‬ بیفزایید؟",
    "Remote share" : "هم‌رسانی دوردست",
    "Remote share password" : "گذرواژهٔ هم‌رسانی دوردست",
    "Cancel" : "لغو",
    "Add remote share" : "افزودن هم‌رسانی دوردست",
    "Invalid Federated Cloud ID" : "شناسهٔ ابری خودگردان نامعتبر",
    "Server to server sharing is not enabled on this server" : "هم‌رسانی کارساز به کارساز روی این کارساز به کار نیفتاده",
    "Couldn't establish a federated share." : "نمی توان یک سهم فدرال ایجاد کرد.",
    "Couldn't establish a federated share, maybe the password was wrong." : "نمی‌توان یک اشتراک فدرال ایجاد کرد، شاید رمز عبور اشتباه بوده است.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "درخواست اشتراک فدرال ارسال شد، یک دعوت نامه دریافت خواهید کرد. اعلان های خود را بررسی کنید.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "نمی‌توان یک اشتراک فدرال ایجاد کرد، به نظر می‌رسد سروری که باید با آن فدرال شود خیلی قدیمی است (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "ارسال اشتراک های گروه فدرال از این سرور مجاز نیست.",
    "Federated shares require read permissions" : "سهام فدرال به مجوز خواندن نیاز دارد",
    "File is already shared with %s" : "فایل قبلاً با به اشتراک گذاشته شده است%s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "اشتراک‌گذاری %1$s انجام نشد، پیدا نشد%2$s، شاید سرور در حال حاضر غیرقابل دسترسی باشد یا از گواهی امضا شده استفاده می‌کند.",
    "Could not find share" : "نتوانست هم‌رسانی را بیابد",
    "Federated sharing" : "هم‌رسانی خودگردان",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "شما {share} را به عنوان یک اشتراک راه دور از {user} دریافت کردید (از طرف {behalf})",
    "You received {share} as a remote share from {user}" : "شما {share} را به عنوان اشتراک راه دور از {user} دریافت کردید",
    "Accept" : "قبول",
    "Decline" : "کاهش می یابد",
    "Federated Cloud Sharing" : "هم‌رسانی ابری خودگردان",
    "Sharing" : "هم‌رسانی",
    "Federated file sharing" : "هم‌رسانی پروندهٔ خودگردان",
    "Provide federated file sharing across servers" : "فراهم‌کنندهٔ هم‌رسانی پروندهٔ خودگردان میان کارسازها",
    "Unable to update federated files sharing config" : "به‌روزرسانی پیکربندی اشتراک‌گذاری فایل‌های فدرال ممکن نیست",
    "Federated Cloud" : "ابر خودگردان",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "می‌توانید با هر کسی که از سرور Nextcloud یا سایر سرورها و سرویس‌های سازگار با Open Cloud Mesh (OCM) استفاده می‌کند، اشتراک‌گذاری کنید! فقط شناسه ابری فدرال آنها را در گفتگوی اشتراک گذاری قرار دهید. به نظر می رسد person@cloud.example.com",
    "Your Federated Cloud ID:" : "شناسهٔ ابردی خودگردانتان:",
    "Share it so your friends can share files with you:" : "آن را به اشتراک بگذارید تا دوستانتان بتوانند فایل ها را با شما به اشتراک بگذارند:",
    "Facebook" : "فیس‌بوک",
    "Twitter" : "توییتر",
    "Diaspora" : "دیازپورا",
    "Add to your website" : "افزودن به پایگاه وبتان",
    "Share with me via Nextcloud" : "هم‌رسانی با من روی نسکت‌کلود",
    "HTML Code:" : "کد HTML :",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "از طریق شناسه ابری فدرال #Nextcloud با من به اشتراک بگذارید، به {url} مراجعه کنید",
    "Share with me through my #Nextcloud Federated Cloud ID" : "از طریق شناسه ابری فدرال #Nextcloud با من به اشتراک بگذارید",
    "Cloud ID copied to the clipboard" : "Cloud ID در کلیپ بورد کپی شد",
    "Copy to clipboard" : "رونوشت به تخته‌گیره",
    "Clipboard is not available" : "کلیپ بورد در دسترس نیست",
    "Copied!" : "رونوشت شد!",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "هم‌رسانی %1$s شکست خورد، چرا که این مورد از پیش با کاربر%2$s هم رسانی شده بود",
    "Not allowed to create a federated share with the same user" : "ایجاد یک هم‌رسانی خودگران با همان کاربر مجاز نیست",
    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "نحوه اشتراک گذاری افراد بین سرورها را تنظیم کنید. این شامل اشتراک گذاری بین کاربران در این سرور نیز می شود، در صورتی که از اشتراک گذاری فدرال استفاده می کنند.",
    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "به کاربران این سرور اجازه می‌دهد تا اشتراک‌ها را به سرورهای دیگر ارسال کنند (این گزینه همچنین به WebDAV اجازه دسترسی به اشتراک‌های عمومی را می‌دهد)",
    "Allow users on this server to receive shares from other servers" : "به کاربران موجود در این سرور اجازه دهید از سرورهای دیگر اشتراک‌گذاری دریافت کنند",
    "Allow users on this server to send shares to groups on other servers" : "به کاربران موجود در این سرور امکان ارسال اشتراک‌ها به گروه‌های موجود در سرورهای دیگر را بدهید",
    "Allow users on this server to receive group shares from other servers" : "به کاربران این سرور اجازه دهید اشتراک‌های گروهی را از سرورهای دیگر دریافت کنند",
    "Search global and public address book for users" : "کتاب آدرس عمومی و عمومی را برای کاربران جستجو کنید",
    "Allow users to publish their data to a global and public address book" : "به کاربران اجازه دهید داده های خود را در یک دفترچه آدرس عمومی و عمومی منتشر کنند"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-31.0.8-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/fa.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "شناسهٔ ابری خودگردان نامعتبر",
    "Server to server sharing is not enabled on this server" : "هم‌رسانی کارساز به کارساز روی این کارساز به کار نیفتاده",
    "Couldn't establish a federated share." : "نمی توان یک سهم فدرال ایجاد کرد.",
    "Couldn't establish a federated share, maybe the password was wrong." : "نمی‌توان یک اشتراک فدرال ایجاد کرد، شاید رمز عبور اشتباه بوده است.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "درخواست اشتراک فدرال ارسال شد، یک دعوت نامه دریافت خواهید کرد. اعلان های خود را بررسی کنید.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "نمی‌توان یک اشتراک فدرال ایجاد کرد، به نظر می‌رسد سروری که باید با آن فدرال شود خیلی قدیمی است (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "ارسال اشتراک های گروه فدرال از این سرور مجاز نیست.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "اشتراک‌گذاری %1$s ناموفق بود، زیرا این مورد قبلاً با حساب %2$s به اشتراک گذاشته شده است",
    "Federated shares require read permissions" : "سهام فدرال به مجوز خواندن نیاز دارد",
    "File is already shared with %s" : "فایل قبلاً با به اشتراک گذاشته شده است%s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "اشتراک‌گذاری %1$s انجام نشد، پیدا نشد%2$s، شاید سرور در حال حاضر غیرقابل دسترسی باشد یا از گواهی امضا شده استفاده می‌کند.",
    "Could not find share" : "نتوانست هم‌رسانی را بیابد",
    "Federated sharing" : "هم‌رسانی خودگردان",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "شما {share} را به عنوان یک اشتراک راه دور از {user} دریافت کردید (از طرف {behalf})",
    "You received {share} as a remote share from {user}" : "شما {share} را به عنوان اشتراک راه دور از {user} دریافت کردید",
    "Accept" : "قبول",
    "Decline" : "کاهش می یابد",
    "Federated Cloud Sharing" : "هم‌رسانی ابری خودگردان",
    "Sharing" : "هم‌رسانی",
    "Federated file sharing" : "هم‌رسانی پروندهٔ خودگردان",
    "Provide federated file sharing across servers" : "فراهم‌کنندهٔ هم‌رسانی پروندهٔ خودگردان میان کارسازها",
    "Unable to update federated files sharing config" : "به‌روزرسانی پیکربندی اشتراک‌گذاری فایل‌های فدرال ممکن نیست",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "از طریق شناسه ابری فدرال #Nextcloud با من به اشتراک بگذارید، به {url} مراجعه کنید",
    "Share with me through my #Nextcloud Federated Cloud ID" : "از طریق شناسه ابری فدرال #Nextcloud با من به اشتراک بگذارید",
    "Share with me via Nextcloud" : "هم‌رسانی با من روی نسکت‌کلود",
    "Copy" : "کپی",
    "Copied!" : "رونوشت شد!",
    "Federated Cloud" : "ابر خودگردان",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "می‌توانید با هر کسی که از سرور Nextcloud یا سایر سرورها و سرویس‌های سازگار با Open Cloud Mesh (OCM) استفاده می‌کند، اشتراک‌گذاری کنید! فقط شناسه ابری فدرال آنها را در گفتگوی اشتراک گذاری قرار دهید. به نظر می رسد person@cloud.example.com",
    "Share it so your friends can share files with you:" : "آن را به اشتراک بگذارید تا دوستانتان بتوانند فایل ها را با شما به اشتراک بگذارند:",
    "Facebook" : "فیس‌بوک",
    "Mastodon" : "Mastodon",
    "Add to your website" : "افزودن به پایگاه وبتان",
    "HTML Code:" : "کد HTML :",
    "Cancel" : "لغو",
    "Add remote share" : "افزودن هم‌رسانی دوردست",
    "Remote share" : "هم‌رسانی دوردست",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "می‌خواهید هم‌رسانی دوردست {name} را از ‪{owner}@{remote}‬ بیفزایید؟",
    "Remote share password" : "گذرواژهٔ هم‌رسانی دوردست",
    "Cloud ID copied to the clipboard" : "Cloud ID در کلیپ بورد کپی شد",
    "Copy to clipboard" : "رونوشت به تخته‌گیره"
},
"nplurals=2; plural=(n > 1);");
